@@ -45,28 +45,37 @@
 #include <sstream>
 #include <cstring>
 #include <cstdio>
+#include <ctime>
 
-namespace CxxTest {
-class TeeOutputStreams {
+namespace CxxTest
+{
+class TeeOutputStreams
+{
 private:
-    class teebuffer : public std::basic_streambuf<char> {
+    class teebuffer : public std::basic_streambuf<char>
+    {
         typedef std::basic_streambuf<char> streambuf_t;
     public:
         teebuffer(streambuf_t * buf1, streambuf_t * buf2)
             : buffer1(buf1), buffer2(buf2)
         {}
 
-        virtual int overflow(int c) {
-            if (c == EOF) {
+        virtual int overflow(int c)
+        {
+            if (c == EOF)
+            {
                 return !EOF;
-            } else {
+            }
+            else
+            {
                 int const ans1 = buffer1->sputc(c);
                 int const ans2 = buffer2->sputc(c);
                 return ans1 == EOF || ans2 == EOF ? EOF : c;
             }
         }
 
-        virtual int sync() {
+        virtual int sync()
+        {
             int ans1 = buffer1->pubsync();
             int ans2 = buffer2->pubsync();
             return ans1 || ans2 ? -1 : 0;
@@ -83,12 +92,14 @@ public:
           orig_cout(_cout),
           orig_cerr(_cerr),
           tee_out(out.rdbuf(), _cout.rdbuf()),
-          tee_err(err.rdbuf(), _cerr.rdbuf()) {
+          tee_err(err.rdbuf(), _cerr.rdbuf())
+    {
         orig_cout.rdbuf(&tee_out);
         orig_cerr.rdbuf(&tee_err);
     }
 
-    ~TeeOutputStreams() {
+    ~TeeOutputStreams()
+    {
         orig_cout.rdbuf(tee_out.buffer2);
         orig_cerr.rdbuf(tee_err.buffer2);
     }
@@ -103,7 +114,8 @@ private:
     teebuffer      tee_err;
 };
 
-class ElementInfo {
+class ElementInfo
+{
 public:
     std::string name;
     std::stringstream value;
@@ -117,7 +129,8 @@ public:
         : name(rhs.name), value(rhs.value.str()), attribute(rhs.attribute)
     {}
 
-    ElementInfo& operator=(const ElementInfo& rhs) {
+    ElementInfo& operator=(const ElementInfo& rhs)
+    {
         name = rhs.name;
         value.str(rhs.value.str());
         attribute = rhs.attribute;
@@ -125,34 +138,43 @@ public:
     }
 
     template <class Type>
-    void add(const std::string& name_, Type& value_) {
+    void add(const std::string& name_, Type& value_)
+    {
         std::ostringstream os;
         os << value_;
         attribute[name_] = os.str();
     }
 
-    void write(OutputStream& os) {
+    void write(OutputStream& os)
+    {
         os << "        <" << name.c_str() << " ";
         std::map<std::string, std::string>::iterator curr = attribute.begin();
         std::map<std::string, std::string>::iterator end = attribute.end();
-        while (curr != end) {
+        while (curr != end)
+        {
             os << curr->first.c_str()
                << "=\"" << curr->second.c_str() << "\" ";
             curr++;
         }
-        if (value.str().empty()) {
+        if (value.str().empty())
+        {
             os << "/>";
-        } else {
+        }
+        else
+        {
             os << ">" << escape(value.str()).c_str()
                << "</" << name.c_str() << ">";
         }
         os.endl(os);
     }
 
-    std::string escape(const std::string& str) {
+    std::string escape(const std::string& str)
+    {
         std::string escStr = "";
-        for (size_t i = 0; i < str.length(); i++) {
-            switch (str[i]) {
+        for (size_t i = 0; i < str.length(); i++)
+        {
+            switch (str[i])
+            {
             case '"':  escStr += "&quot;"; break;
             case '\'': escStr += "&apos;"; break;
             case '<':  escStr += "&lt;"; break;
@@ -166,7 +188,8 @@ public:
 
 };
 
-class TestCaseInfo {
+class TestCaseInfo
+{
 public:
 
     TestCaseInfo() : fail(false), error(false), runtime(0.0) {}
@@ -180,32 +203,39 @@ public:
     typedef std::list<ElementInfo>::iterator element_t;
     std::string world;
 
-    element_t add_element(const std::string& name) {
+    element_t add_element(const std::string& name)
+    {
         element_t elt = elements.insert(elements.end(), ElementInfo());
         elt->name = name;
         return elt;
     }
 
-    element_t update_element(const std::string& name) {
+    element_t update_element(const std::string& name)
+    {
         element_t elt = elements.begin();
-        while (elt != elements.end()) {
-            if (elt->name == name) {
+        while (elt != elements.end())
+        {
+            if (elt->name == name)
+            {
                 return elt;
-            elt++;
             }
+            elt++;
         }
         return add_element(name);
     }
 
-    void write(OutputStream &o) {
+    void write(OutputStream &o)
+    {
         o << "    <testcase classname=\"" << className.c_str()
           << "\" name=\"" << testName.c_str()
           << "\" line=\"" << line.c_str() << "\"";
         bool elts = false;
         element_t curr = elements.begin();
         element_t end  = elements.end();
-        while (curr != end) {
-            if (!elts) {
+        while (curr != end)
+        {
+            if (!elts)
+            {
                 o << ">";
                 o.endl(o);
                 elts = true;
@@ -213,9 +243,12 @@ public:
             curr->write(o);
             curr++;
         }
-        if (elts) {
+        if (elts)
+        {
             o << "    </testcase>";
-        } else {
+        }
+        else
+        {
             o << " />";
         }
         o.endl(o);
@@ -223,7 +256,8 @@ public:
 
 };
 
-class XmlFormatter : public TestListener {
+class XmlFormatter : public TestListener
+{
 public:
     XmlFormatter(OutputStream *o, OutputStream *ostr, std::ostringstream *os)
         : _o(o), _ostr(ostr), _os(os), stream_redirect(NULL)
@@ -238,34 +272,40 @@ public:
     int nerror;
     double totaltime;
 
-    int run() {
+    int run()
+    {
         TestRunner::runAllTests(*this);
         return tracker().failedTests();
     }
 
-    void enterWorld(const WorldDescription & /*desc*/) {
+    void enterWorld(const WorldDescription & /*desc*/)
+    {
         ntests = 0;
         nfail = 0;
         nerror = 0;
         totaltime = 0;
     }
 
-    static void totalTests(OutputStream &o) {
+    static void totalTests(OutputStream &o)
+    {
         char s[WorldDescription::MAX_STRLEN_TOTAL_TESTS];
         const WorldDescription &wd = tracker().world();
         o << wd.strTotalTests(s)
           << (wd.numTotalTests() == 1 ? " test" : " tests");
     }
 
-    void enterSuite(const SuiteDescription& desc) {
+    void enterSuite(const SuiteDescription& desc)
+    {
         classname = desc.suiteName();
         // replace "::" namespace with java-style "."
         size_t pos = 0;
         while ((pos = classname.find("::", pos)) !=
-                CXXTEST_STD(string::npos)) {
+                CXXTEST_STD(string::npos))
+        {
             classname.replace(pos, 2, ".");
         }
-        while (! classname.empty() && classname[0] == '.') {
+        while (! classname.empty() && classname[0] == '.')
+        {
             classname.erase(0, 1);
         }
 
@@ -278,10 +318,12 @@ public:
         //_o->flush();
     }
 
-    void leaveSuite(const SuiteDescription &) {
+    void leaveSuite(const SuiteDescription &)
+    {
         std::list<TestCaseInfo>::iterator curr = info.begin();
         std::list<TestCaseInfo>::iterator end  = info.end();
-        while (curr != end) {
+        while (curr != end)
+        {
             if (curr->fail) { nfail++; }
             if (curr->error) { nerror++; }
             totaltime += curr->runtime;
@@ -290,14 +332,16 @@ public:
         }
         curr = info.begin();
         end  = info.end();
-        while (curr != end) {
+        while (curr != end)
+        {
             (*curr).write(*_ostr);
             curr++;
         }
         info.clear();
     }
 
-    void enterTest(const TestDescription & desc) {
+    void enterTest(const TestDescription & desc)
+    {
         testcase = info.insert(info.end(), TestCaseInfo());
         testcase->testName = desc.testName();
         testcase->className = classname;
@@ -313,16 +357,21 @@ public:
             new TeeOutputStreams(CXXTEST_STD(cout), CXXTEST_STD(cerr));
     }
 
-    void leaveTest(const TestDescription &) {
-        if (stream_redirect != NULL) {
+    void leaveTest(const TestDescription &)
+    {
+        if (stream_redirect != NULL)
+        {
             std::string out = stream_redirect->out.str();
-            if (! out.empty()) {
+            if (! out.empty())
+            {
                 // silently ignore the '.'
-                if (out[0] != '.' || out.size() > 1) {
+                if (out[0] != '.' || out.size() > 1)
+                {
                     testcase->add_element("system-out")->value << out;
                 }
             }
-            if (! stream_redirect->err.str().empty()) {
+            if (! stream_redirect->err.str().empty())
+            {
                 testcase->add_element("system-err")->value << stream_redirect->err.str();
             }
 
@@ -331,12 +380,22 @@ public:
         }
     }
 
-    void leaveWorld(const WorldDescription& desc) {
+    void leaveWorld(const WorldDescription& desc)
+    {
         std::ostringstream os;
+        const time_t current_date(time(0));
+        char current_date_string[27];
+        const size_t n = strlen(ctime_r(&current_date,current_date_string));
+        if (n) {
+            current_date_string[n-1] = '\0'; // remove the ending \n
+        } else {
+            current_date_string[0] = '\0'; // just in case...
+        }
         os << totaltime;
         (*_o) << "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>" << endl;
         (*_o) << "<testsuite name=\"" << desc.worldName() << "\" ";
-        (*_o) << " tests=\"" << ntests
+        (*_o) << "date=\"" << current_date_string;
+        (*_o) << "\" tests=\"" << ntests
               << "\" errors=\"" << nerror
               << "\" failures=\"" << nfail
               << "\" time=\"" << os.str().c_str() << "\" >";
@@ -347,34 +406,40 @@ public:
         _o->flush();
     }
 
-    void trace(const char* /*file*/, int line, const char *expression) {
+    void trace(const char* /*file*/, int line, const char *expression)
+    {
         element_t elt = testcase->add_element("trace");
         elt->add("line", line);
         elt->value << expression;
     }
 
-    void warning(const char* /*file*/, int line, const char *expression) {
+    void warning(const char* /*file*/, int line, const char *expression)
+    {
         element_t elt = testcase->add_element("warning");
         elt->add("line", line);
         elt->value << expression;
     }
 
-    void skippedTest(const char* file, int line, const char* expression) {
+    void skippedTest(const char* file, int line, const char* expression)
+    {
         testSkipped(file, line, "skipped") << "Test skipped: " << expression;
     }
 
-    void failedTest(const char* file, int line, const char* expression) {
+    void failedTest(const char* file, int line, const char* expression)
+    {
         testFailure(file, line, "failure") << "Test failed: " << expression;
     }
 
-    void failedAssert(const char *file, int line, const char *expression) {
+    void failedAssert(const char *file, int line, const char *expression)
+    {
         testFailure(file, line, "failedAssert")
                 << "Assertion failed: " << expression;
     }
 
     void failedAssertEquals(const char *file, int line,
                             const char* xStr, const char* yStr,
-                            const char *x, const char *y) {
+                            const char *x, const char *y)
+    {
         testFailure(file, line, "failedAssertEquals")
                 << "Error: Expected ("
                 << xStr << " == " << yStr << "), found ("
@@ -383,7 +448,8 @@ public:
 
     void failedAssertSameData(const char *file, int line,
                               const char *xStr, const char *yStr, const char *sizeStr,
-                              const void* /*x*/, const void* /*y*/, unsigned size) {
+                              const void* /*x*/, const void* /*y*/, unsigned size)
+    {
         testFailure(file, line, "failedAssertSameData")
                 << "Error: Expected " << sizeStr
                 << " (" << size << ")  bytes to be equal at ("
@@ -393,14 +459,16 @@ public:
     void failedAssertSameFiles(const char *file, int line,
                                const char *, const char *,
                                const char* explanation
-                              ) {
+                              )
+    {
         testFailure(file, line, "failedAssertSameFiles")
                 << "Error: " << explanation;
     }
 
     void failedAssertDelta(const char *file, int line,
                            const char *xStr, const char *yStr, const char *dStr,
-                           const char *x, const char *y, const char *d) {
+                           const char *x, const char *y, const char *d)
+    {
         testFailure(file, line, "failedAssertDelta")
                 << "Error: Expected ("
                 << xStr << " == " << yStr << ") up to " << dStr
@@ -410,7 +478,8 @@ public:
 
     void failedAssertDiffers(const char *file, int line,
                              const char *xStr, const char *yStr,
-                             const char *value) {
+                             const char *value)
+    {
         testFailure(file, line, "failedAssertDiffers")
                 << "Error: Expected ("
                 << xStr << " != " << yStr << "), found ("
@@ -419,7 +488,8 @@ public:
 
     void failedAssertLessThan(const char *file, int line,
                               const char *xStr, const char *yStr,
-                              const char *x, const char *y) {
+                              const char *x, const char *y)
+    {
         testFailure(file, line, "failedAssertLessThan")
                 << "Error: Expected (" <<
                 xStr << " < " << yStr << "), found (" <<
@@ -428,7 +498,8 @@ public:
 
     void failedAssertLessThanEquals(const char *file, int line,
                                     const char *xStr, const char *yStr,
-                                    const char *x, const char *y) {
+                                    const char *x, const char *y)
+    {
         testFailure(file, line, "failedAssertLessThanEquals")
                 << "Error: Expected (" <<
                 xStr << " <= " << yStr << "), found (" <<
@@ -437,7 +508,8 @@ public:
 
     void failedAssertRelation(const char *file, int line,
                               const char *relation, const char *xStr, const char *yStr,
-                              const char *x, const char *y) {
+                              const char *x, const char *y)
+    {
         testFailure(file, line, "failedAssertRelation")
                 << "Error: Expected " << relation << "( " <<
                 xStr << ", " << yStr << " ), found !" << relation
@@ -445,7 +517,8 @@ public:
     }
 
     void failedAssertPredicate(const char *file, int line,
-                               const char *predicate, const char *xStr, const char *x) {
+                               const char *predicate, const char *xStr, const char *x)
+    {
         testFailure(file, line, "failedAssertPredicate")
                 << "Error: Expected " << predicate << "( " <<
                 xStr << " ), found !" << predicate << "( " << x << " )";
@@ -453,14 +526,16 @@ public:
 
     void failedAssertThrows(const char *file, int line,
                             const char *expression, const char *type,
-                            bool otherThrown) {
+                            bool otherThrown)
+    {
         testFailure(file, line, "failedAssertThrows")
                 << "Error: Expected (" << expression << ") to throw ("  <<
                 type << ") but it "
                 << (otherThrown ? "threw something else" : "didn't throw");
     }
 
-    void failedAssertThrowsNot(const char *file, int line, const char *expression) {
+    void failedAssertThrowsNot(const char *file, int line, const char *expression)
+    {
         testFailure(file, line, "failedAssertThrowsNot")
                 << "Error: Expected (" << expression
                 << ") not to throw, but it did";
@@ -468,11 +543,13 @@ public:
 
 protected:
 
-    OutputStream *outputStream() const {
+    OutputStream *outputStream() const
+    {
         return _o;
     }
 
-    OutputStream *outputFileStream() const {
+    OutputStream *outputFileStream() const
+    {
         return _ostr;
     }
 
@@ -480,60 +557,74 @@ private:
     XmlFormatter(const XmlFormatter &);
     XmlFormatter &operator=(const XmlFormatter &);
 
-    std::stringstream& testFailure(const char* file, int line, const char *failureType) {
+    std::stringstream& testFailure(const char* file, int line, const char *failureType)
+    {
         testcase->fail = true;
         element_t elt = testcase->update_element("failure");
-        if (elt->value.str().empty()) {
+        if (elt->value.str().empty())
+        {
             elt->add("type", failureType);
             elt->add("line", line);
             elt->add("file", file);
-        } else {
+        }
+        else
+        {
             elt->value << CXXTEST_STD(endl);
         }
         return elt->value;
         //failedTest(file,line,message.c_str());
     }
 
-    std::stringstream& testSkipped(const char* file, int line, const char *failureType) {
+    std::stringstream& testSkipped(const char* file, int line, const char *failureType)
+    {
         //testcase->fail = true;
         element_t elt = testcase->update_element("skipped");
-        if (elt->value.str().empty()) {
+        if (elt->value.str().empty())
+        {
             elt->add("type", failureType);
             elt->add("line", line);
             elt->add("file", file);
-        } else {
+        }
+        else
+        {
             elt->value << CXXTEST_STD(endl);
         }
         return elt->value;
     }
 
 #if 0
-    void attributeBinary(const char* name, const void *value, unsigned size) {
+    void attributeBinary(const char* name, const void *value, unsigned size)
+    {
         (*_o) << name;
         (*_o) << "=\"";
         dump(value, size);
         (*_o) << "\" ";
     }
 
-    void dump(const void *buffer, unsigned size) {
+    void dump(const void *buffer, unsigned size)
+    {
         if (!buffer) { return; }
 
         unsigned dumpSize = size;
-        if (maxDumpSize() && dumpSize > maxDumpSize()) {
+        if (maxDumpSize() && dumpSize > maxDumpSize())
+        {
             dumpSize = maxDumpSize();
         }
 
         const unsigned char *p = (const unsigned char *)buffer;
-        for (unsigned i = 0; i < dumpSize; ++ i) {
+        for (unsigned i = 0; i < dumpSize; ++ i)
+        {
             (*_o) << byteToHex(*p++) << " ";
         }
-        if (dumpSize < size) {
+        if (dumpSize < size)
+        {
             (*_o) << "... ";
         }
     }
 #endif
 
-    static void endl(OutputStream &o) {
+    static void endl(OutputStream &o)
+    {
         OutputStream::endl(o);
     }
 
