@@ -55,9 +55,10 @@ import ply.yacc as yacc
 import re
 try:
     from collections import OrderedDict
-except ImportError:
+except ImportError:             #pragma: no cover
     from ordereddict import OrderedDict
 
+# global data
 lexer = None
 scope_lineno = 0
 identifier_lineno = {}
@@ -65,6 +66,7 @@ _parse_info=None
 _parsedata=None
 noExceptionLogic = True
 
+
 def ply_init(data):
     global _parsedata
     _parsedata=data
@@ -2100,6 +2102,22 @@ def p_error(p):
 # The function that performs the parsing
 #
 def parse_cpp(data=None, filename=None, debug=0, optimize=0, verbose=False, func_filter=None):
+    #
+    # Reset global data
+    #
+    global lexer
+    lexer = None
+    global scope_lineno
+    scope_lineno = 0
+    global indentifier_lineno
+    identifier_lineno = {}
+    global _parse_info
+    _parse_info=None
+    global _parsedata
+    _parsedata=None
+    global noExceptionLogic
+    noExceptionLogic = True
+    #
     if debug > 0:
         print("Debugging parse_cpp!")
         #
@@ -2120,12 +2138,10 @@ def parse_cpp(data=None, filename=None, debug=0, optimize=0, verbose=False, func
     #
     # Build lexer
     #
-    global lexer
     lexer = lex.lex()
     #
     # Initialize parse object
     #
-    global _parse_info
     _parse_info = CppInfo(filter=func_filter)
     _parse_info.verbose=verbose
     #
@@ -2136,7 +2152,6 @@ def parse_cpp(data=None, filename=None, debug=0, optimize=0, verbose=False, func
     #
     # Parse the file
     #
-    global _parsedata
     if not data is None:
         _parsedata=data
         ply_init(_parsedata)
@@ -2166,7 +2181,7 @@ def parse_cpp(data=None, filename=None, debug=0, optimize=0, verbose=False, func
 
 import sys
 
-if __name__ == '__main__':
+if __name__ == '__main__':  #pragma: no cover
     #
     # This MAIN routine parses a sequence of files provided at the command
     # line.  If '-v' is included, then a verbose parsing output is 
