@@ -37,15 +37,15 @@ try:
 except ImportError:
     from .cxxtest_misc import relpath
 
+# Global data is initialized by main()
 options = []
 suites = []
-
 wrotePreamble = 0
 wroteWorld = 0
 lastIncluded = ''
 
 
-def main(args=sys.argv):
+def main(args=sys.argv, catch=False):
     '''The main program'''
     #
     # Reset global state
@@ -56,15 +56,21 @@ def main(args=sys.argv):
     wroteWorld=0
     global lastIncluded
     lastIncluded = ''
-
     global suites
+    suites = []
     global options
-    files = parseCommandline(args)
-    if imported_fog and options.fog:
-        [options,suites] = cxxtest_fog.scanInputFiles( files, options )
-    else:
-        [options,suites] = cxxtest_parser.scanInputFiles( files, options )
-    writeOutput()
+    options = []
+    #
+    try:
+        files = parseCommandline(args)
+        if imported_fog and options.fog:
+            [options,suites] = cxxtest_fog.scanInputFiles( files, options )
+        else:
+            [options,suites] = cxxtest_parser.scanInputFiles( files, options )
+        writeOutput()
+    except SystemExit:
+        if not catch:
+            raise
 
 def create_parser(asciidoc=False):
     parser = OptionParser("cxxtestgen [options] [<filename> ...]")
